---
name: "Dataset viewer issue"
about: Issue related to the dataset viewer on huggingface.co.
title: ''
labels: 'dataset-viewer'
assignees: ''
---

## Dataset viewer issue for '*name of the dataset*'

**Link:** *link to the dataset viewer page*

*short description of the issue*

Am I the one who added this dataset ? Yes-No
